==> humhub-1.17.4.zip: humhub-1.17.4/protected/humhub/modules/user/messages/lt/account.php <==
<?php

return [
    '<strong>Account</strong> Settings' => '<strong>Paskyros</strong> Nustatymai',
    '<strong>Confirm</strong></strong> your new email address' => '<strong>Patvirtinkite </strong> savo naująjį elektroninio pašto adresą',
    '<strong>Permissions</strong>' => '<strong>Leidimai</strong>',
    '<strong>Your</strong> Account' => '<strong>Jūsų</strong>Paskyra',
    '<strong>Your</strong> profile' => '<strong>Jūsų</strong> profilis',
    'Add tags to your profile describing you and highlighting your skills and interests. Your tags will be displayed in your profile and in the \'People\' directory.' => 'Į savo profilį įtraukite žymas, apibūdinančias jus ir pabrėžiančias jūsų įgūdžius bei pomėgius. Žymos bus rodomos jūsų profilyje ir skyriuje "Žmonės".',
    'All your personal data will be irrevocably deleted.' => 'Visi jūsų asmens duomenys bus neatšaukiamai ištrinti.',
    'Are you sure that you want to delete your account?' => 'Ar tikrai norite ištrinti savo paskyrą?',
    'Blocked users' => 'Užblokuoti vartotojai',
    'Changing the username can make some links unusable, for example old links to the profile.' => 'Pakeitus vartotojo vardą kai kurios nuorodos gali tapti nenaudojamos, pavyzdžiui, senos profilio nuorodos.',
    'Confirm' => 'Patvirtinti',
    'Current password' => 'Dabartinis slaptažodis',
    'Define basic settings for your profile. You can add tags that fit you, choose the language and your time zone and block impolite users.' => 'Nustatykite pagrindinius profilio nustatymus. Galite pridėti jums tinkančias žymas, pasirinkti kalbą ir laiko juostą bei blokuoti nemandagius naudotojus.',
    'Delete account' => 'Ištrinti paskyrą',
    'Do you really want to delete your icon image?' => 'Ar tikrai norite ištrinti savo piktogramą?',
    'Do you really want to delete your logo image?' => 'Ar tikrai norite ištrinti savo logotipo paveikslėlį?',
    'E-Mail' => 'Elektroninio pašto adresas',
    'E-Mail change' => 'Elektroninio pašto keitimas',
    'Enter your password to continue' => 'Įveskite slaptažodį, norint tęsti',
    'General' => 'Pagrindinis',
    'Hello' => 'Sveiki',
    'Here you can edit your general profile data, which is visible in the about page of your profile.' => 'Čia galite redaguoti bendruosius profilio duomenis, kurie matomi profilio puslapyje apie jus.',
    'Hide introduction tour panel on dashboard' => 'Slėpti įvadinio turo skydelį prietaisų skydelyje',
    'Hide my online status' => 'Slėpti mano interneto būseną',
    'Invalid link! Please make sure that you entered the entire url.' => 'Neteisinga nuoroda! Patikrinkite ar įvedėte pilną adresą (URL).',
    'Language' => 'Kalba',
    'Markdown Editor Mode' => '"Markdown" redagavimo režimas',
    'Modules' => 'Moduliai',
    'New E-Mail address' => 'Naujas elektronio pašto adresas',
    'New User name' => 'Naujas Vartotojo Vardas',
    'Not registered users' => 'Neregistruoti vartotojai',
    'Notifications' => 'Pranešimai',
    'Other users' => 'Kiti vartotojai',
    'Password Recovery' => 'Atkurti slaptažodį',
    'Permissions' => 'Leidimai',
    'Plain' => 'Paprastai',
    'Profile' => 'Profilis',
    'Profile Tags' => 'Profilio žymos',
    'Profile visibility' => 'Profilio matomumas',
    'Registered users only' => 'Tik registruoti vartotojai',
    'Rich Text' => 'Sodrus tekstas',
    'Save' => 'Išsaugoti',
    'Save profile' => 'Išsaugoti profilį',
    'The entered e-mail address is already in use by another user.' => 'Šis elektroninis paštaus jau yra naudojamas.',
    'These settings allow you to determine which permissions you want to grant visitors of your own individual profile. Each user can freely adjust the settings for his or her own profile.' => 'Šie nustatymai leidžia nustatyti, kokias teises norite suteikti savo individualaus profilio lankytojams. Kiekvienas naudotojas gali laisvai keisti savo profilio nustatymus.',
    'TimeZone' => 'Laiko Juosta',
    'Username has been changed' => 'Vartotojo vardas pakeistas',
    'Users' => 'Vartotojai',
    'Visible for all (also unregistered users)' => 'Visiems matomas (ir neregistruotiems vartotojams)',
    'We´ve just sent an confirmation e-mail to your new address. <br /> Please follow the instructions inside.' => 'Mes kątik atsiuntėme patvirtinimą Jūsų naujuoju elektroninio pašto adresu. <br>Prašome sekti laiške nurodytas instrukcijas.',
    'You are currently the owner of following spaces:' => 'Šiuo metu esate šių erdvių savininkas:',
    'You cannot use this username.' => 'Šio vartotojo vardo naudoti negalima.',
    'You have requested to change your e-mail address.<br>Your new e-mail address is {newemail}.<br><br>To confirm your new e-mail address please click on the button below.' => 'Jūs prašėte pakeisti jūsų elektroninio pašto adresą.<br>Jūsų naujasis elektroninio pašto adresas yra {newemail}.<br><br> Norint patvirtinti naująjį elektroninio pašto adresą, prašome paspausti mygtuką žemiau.',
    'You have successfully changed your username.<br>Your new username is {newUsername}.' => 'Sėkmingai pakeitėte savo vartotojo vardą.<br>Jūsų naujasis vartotojo vardas yra {newUsername}.',
    'You must transfer ownership or delete these spaces before you can delete your account.' => 'Prieš ištrindami savo paskyrą turite perduoti nuosavybę arba ištrinti šias vietas.',
    'Your account cannot be deleted!' => 'Jūsų paskyra negali būti ištrinta',
    'Your current E-mail address is <b>{email}</b>. You can change your current E-mail address here.' => 'Dabartinis jūsų el. pašto adresas yra <b>{email}</b>. Jį pakeisti galite čia.',
    'Your current password can be changed here.' => 'Dabartinį slaptažodį galite pakeisti čia.',
    'Your current username is <b>{username}</b>. You can change your current username here.' => 'Dabartinis jūsų vartotojo vardas yra <b>{username}</b>. Dabartinį vartotojo vardą galite pakeisti čia.',
    'Your e-mail address has been successfully changed to {email}.' => 'Jūsų elektroninio pašto adresas sėkmingai pakeistas į {email}.',
    'Your friends' => 'Jūsų Draugai',
    'Your password has been successfully changed!' => 'Jūsų slaptažodis sėkmingai pakeistas!',
    'Your username has been changed' => 'Jūsų vartotojo vardas pakeistas',
    'Your username has been successfully changed. <br> We´ve just sent an e-mail to you with new information.' => 'Jūsų vartotojo vardas buvo sėkmingai pakeistas.<br> Ką tik išsiuntėme jums el. laišką su nauja informacija.',
    'Password recovery can only be initiated once every 10 minutes.' => '',
    'Password recovery disabled. Please contact your system administrator.' => '',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/modules/user/messages/lt/account.php <==
<?php

return [
    '<strong>Account</strong> Settings' => '<strong>Paskyros</strong> Nustatymai',
    '<strong>Confirm</strong></strong> your new email address' => '<strong>Patvirtinkite </strong> savo naująjį elektroninio pašto adresą',
    '<strong>Permissions</strong>' => '<strong>Leidimai</strong>',
    '<strong>Your</strong> Account' => '<strong>Jūsų</strong>Paskyra',
    '<strong>Your</strong> profile' => '<strong>Jūsų</strong> profilis',
    'Add tags to your profile describing you and highlighting your skills and interests. Your tags will be displayed in your profile and in the \'People\' directory.' => 'Į savo profilį įtraukite žymas, apibūdinančias jus ir pabrėžiančias jūsų įgūdžius bei pomėgius. Žymos bus rodomos jūsų profilyje ir skyriuje "Žmonės".',
    'All your personal data will be irrevocably deleted.' => 'Visi jūsų asmens duomenys bus neatšaukiamai ištrinti.',
    'Are you sure that you want to delete your account?' => 'Ar tikrai norite ištrinti savo paskyrą?',
    'Blocked users' => 'Užblokuoti vartotojai',
    'Changing the username can make some links unusable, for example old links to the profile.' => 'Pakeitus vartotojo vardą kai kurios nuorodos gali tapti nenaudojamos, pavyzdžiui, senos profilio nuorodos.',
    'Confirm' => 'Patvirtinti',
    'Current password' => 'Dabartinis slaptažodis',
    'Define basic settings for your profile. You can add tags that fit you, choose the language and your time zone and block impolite users.' => 'Nustatykite pagrindinius profilio nustatymus. Galite pridėti jums tinkančias žymas, pasirinkti kalbą ir laiko juostą bei blokuoti nemandagius naudotojus.',
    'Delete account' => 'Ištrinti paskyrą',
    'Do you really want to delete your icon image?' => 'Ar tikrai norite ištrinti savo piktogramą?',
    'Do you really want to delete your logo image?' => 'Ar tikrai norite ištrinti savo logotipo paveikslėlį?',
    'E-Mail' => 'Elektroninio pašto adresas',
    'E-Mail change' => 'Elektroninio pašto keitimas',
    'Enter your password to continue' => 'Įveskite slaptažodį, norint tęsti',
    'General' => 'Pagrindinis',
    'Hello' => 'Sveiki',
    'Here you can edit your general profile data, which is visible in the about page of your profile.' => 'Čia galite redaguoti bendruosius profilio duomenis, kurie matomi profilio puslapyje apie jus.',
    'Hide introduction tour panel on dashboard' => 'Slėpti įvadinio turo skydelį prietaisų skydelyje',
    'Hide my online status' => 'Slėpti mano interneto būseną',
    'Invalid link! Please make sure that you entered the entire url.' => 'Neteisinga nuoroda! Patikrinkite ar įvedėte pilną adresą (URL).',
    'Language' => 'Kalba',
    'Markdown Editor Mode' => '"Markdown" redagavimo režimas',
    'Modules' => 'Moduliai',
    'New E-Mail address' => 'Naujas elektronio pašto adresas',
    'New User name' => 'Naujas Vartotojo Vardas',
    'Not registered users' => 'Neregistruoti vartotojai',
    'Notifications' => 'Pranešimai',
    'Other users' => 'Kiti vartotojai',
    'Password Recovery' => 'Atkurti slaptažodį',
    'Permissions' => 'Leidimai',
    'Plain' => 'Paprastai',
    'Profile' => 'Profilis',
    'Profile Tags' => 'Profilio žymos',
    'Profile visibility' => 'Profilio matomumas',
    'Registered users only' => 'Tik registruoti vartotojai',
    'Rich Text' => 'Sodrus tekstas',
    'Save' => 'Išsaugoti',
    'Save profile' => 'Išsaugoti profilį',
    'The entered e-mail address is already in use by another user.' => 'Šis elektroninis paštaus jau yra naudojamas.',
    'These settings allow you to determine which permissions you want to grant visitors of your own individual profile. Each user can freely adjust the settings for his or her own profile.' => 'Šie nustatymai leidžia nustatyti, kokias teises norite suteikti savo individualaus profilio lankytojams. Kiekvienas naudotojas gali laisvai keisti savo profilio nustatymus.',
    'TimeZone' => 'Laiko Juosta',
    'Username has been changed' => 'Vartotojo vardas pakeistas',
    'Users' => 'Vartotojai',
    'Visible for all (also unregistered users)' => 'Visiems matomas (ir neregistruotiems vartotojams)',
    'We´ve just sent an confirmation e-mail to your new address. <br /> Please follow the instructions inside.' => 'Mes kątik atsiuntėme patvirtinimą Jūsų naujuoju elektroninio pašto adresu. <br>Prašome sekti laiške nurodytas instrukcijas.',
    'You are currently the owner of following spaces:' => 'Šiuo metu esate šių erdvių savininkas:',
    'You cannot use this username.' => 'Šio vartotojo vardo naudoti negalima.',
    'You have requested to change your e-mail address.<br>Your new e-mail address is {newemail}.<br><br>To confirm your new e-mail address please click on the button below.' => 'Jūs prašėte pakeisti jūsų elektroninio pašto adresą.<br>Jūsų naujasis elektroninio pašto adresas yra {newemail}.<br><br> Norint patvirtinti naująjį elektroninio pašto adresą, prašome paspausti mygtuką žemiau.',
    'You have successfully changed your username.<br>Your new username is {newUsername}.' => 'Sėkmingai pakeitėte savo vartotojo vardą.<br>Jūsų naujasis vartotojo vardas yra {newUsername}.',
    'You must transfer ownership or delete these spaces before you can delete your account.' => 'Prieš ištrindami savo paskyrą turite perduoti nuosavybę arba ištrinti šias vietas.',
    'Your account cannot be deleted!' => 'Jūsų paskyra negali būti ištrinta',
    'Your current E-mail address is <b>{email}</b>. You can change your current E-mail address here.' => 'Dabartinis jūsų el. pašto adresas yra <b>{email}</b>. Jį pakeisti galite čia.',
    'Your current password can be changed here.' => 'Dabartinį slaptažodį galite pakeisti čia.',
    'Your current username is <b>{username}</b>. You can change your current username here.' => 'Dabartinis jūsų vartotojo vardas yra <b>{username}</b>. Dabartinį vartotojo vardą galite pakeisti čia.',
    'Your e-mail address has been successfully changed to {email}.' => 'Jūsų elektroninio pašto adresas sėkmingai pakeistas į {email}.',
    'Your friends' => 'Jūsų Draugai',
    'Your password has been successfully changed!' => 'Jūsų slaptažodis sėkmingai pakeistas!',
    'Your username has been changed' => 'Jūsų vartotojo vardas pakeistas',
    'Your username has been successfully changed. <br> We´ve just sent an e-mail to you with new information.' => 'Jūsų vartotojo vardas buvo sėkmingai pakeistas.<br> Ką tik išsiuntėme jums el. laišką su nauja informacija.',
    'Do you really want to delete your login background image?' => '',
    'Do you really want to delete your mail header image?' => '',
    'Password recovery can only be initiated once every 10 minutes.' => '',
    'Password recovery disabled. Please contact your system administrator.' => '',
];
